==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-share/app/translations/peony-share-extension_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="58"/>
        <source>Advanced share</source>
        <translation>高级共享</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="106"/>
        <source>Samba set user password</source>
        <translation>Samba设置用户密码</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="106"/>
        <source>Samba password:</source>
        <translation>Samba密码：</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="110"/>
        <location filename="../advanced-share-page.cpp" line="122"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="110"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Samba设置密码失败，请重新输入!</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="118"/>
        <source>Tips</source>
        <translation>提示</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="118"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>该用户没有设置samba密码。你需要登录%1用户，可以在文件管理器的右上菜单中进行设置samba密码</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="122"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>共享配置服务异常，请确认是否有正在进行的共享配置操作，或者请重新设置共享！</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>User</source>
        <translation>用户</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Writable</source>
        <translation>可写</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Readonly</source>
        <translation>只读</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="263"/>
        <source>Reject</source>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="358"/>
        <source>Share permission settings</source>
        <translation>共享权限设置</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="370"/>
        <source>delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="387"/>
        <source>Add</source>
        <translation>增加</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="404"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="405"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>共享</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>允许共享文件夹</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="435"/>
        <source>Share folder</source>
        <translation>共享文件夹</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="130"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>该文件夹当前共享模式为非只读模式，是否需要自动增加当前文件夹增加其他人的写权限？</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="131"/>
        <location filename="../share-page.cpp" line="185"/>
        <source>question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="133"/>
        <location filename="../share-page.cpp" line="187"/>
        <source>Confirm adding permissions</source>
        <translation>确定增加权限</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="134"/>
        <location filename="../share-page.cpp" line="188"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <location filename="../share-page.cpp" line="113"/>
        <location filename="../share-page.cpp" line="162"/>
        <location filename="../share-page.cpp" line="171"/>
        <location filename="../share-page.cpp" line="217"/>
        <location filename="../share-page.cpp" line="227"/>
        <location filename="../share-page.cpp" line="271"/>
        <location filename="../share-page.cpp" line="300"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="108"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>共享名不能包含%1，并且不能以-开头或者空格开头，或者空格结尾</translation>
    </message>
    <message>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation type="vanished">该文件夹当前共享设置了匿名访问，是否需要自动增加当前文件和祖宗目录的其他人的可执行权限？</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="113"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation>共享文件名不能和已有用系统户名一致</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="184"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically add executable permissions for the current file and all other members of the parent directory?</source>
        <translation>该文件夹当前共享设置了匿名访问，是否需要自动增加当前文件和祖宗目录的其他人的可执行权限？</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="271"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>共享配置服务异常，请确认是否有正在进行的共享配置操作，或者请重新设置共享！</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="280"/>
        <source>Samba set user password</source>
        <translation>Samba设置用户密码</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="280"/>
        <source>Samba password:</source>
        <translation>Samba密码：</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="300"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Samba设置密码失败，请重新输入!</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="402"/>
        <source>usershare</source>
        <translation>本机共享</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="406"/>
        <location filename="../share-page.cpp" line="451"/>
        <source>share this folder</source>
        <translation>共享此文件夹</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="406"/>
        <location filename="../share-page.cpp" line="458"/>
        <source>don`t share this folder</source>
        <translation>不共享此文件夹</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="486"/>
        <source>Share name:</source>
        <translation>共享名：</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="491"/>
        <source>Allow others to create and delete files</source>
        <translation>允许其它人创建和删除文件</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="vanished">只读</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="494"/>
        <source>Allow Anonymous</source>
        <translation>允许游客访问</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="503"/>
        <source>Advanced Sharing</source>
        <translation>高级共享</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="487"/>
        <source>Comment:</source>
        <translation>注释:</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-share/app/translations/peony-share-extension_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AdvancedSharePage</name>
    <message>
        <location filename="../advanced-share-page.cpp" line="58"/>
        <source>Advanced share</source>
        <translation>高级共享</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="109"/>
        <source>Samba set user password</source>
        <translation>Samba设置用户密码</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="107"/>
        <source>Samba password:</source>
        <translation>Samba密码：</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="117"/>
        <location filename="../advanced-share-page.cpp" line="129"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="117"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Samba设置密码失败，请重新输入!</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="125"/>
        <source>Tips</source>
        <translation>提示</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="125"/>
        <source>The user has not set the samba password. If you need to log in to %1, you can set it in the upper right menu of the file manager</source>
        <translation>该用户没有设置samba密码。你需要登录%1用户，可以在文件管理器的右上菜单中进行设置samba密码</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="129"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>共享配置服务异常，请确认是否有正在进行的共享配置操作，或者请重新设置共享！</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>User</source>
        <translation>用户</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Writable</source>
        <translation>可写</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Readonly</source>
        <translation>只读</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="270"/>
        <source>Reject</source>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="365"/>
        <source>Share permission settings</source>
        <translation>共享权限设置</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="377"/>
        <source>delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="394"/>
        <source>Add</source>
        <translation>增加</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="411"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../advanced-share-page.cpp" line="412"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>NetUsershareHelper</name>
    <message>
        <source>Peony-Qt-Share-Extension</source>
        <translation type="vanished">共享</translation>
    </message>
</context>
<context>
    <name>Peony::SharePropertiesPagePlugin</name>
    <message>
        <location filename="../share-properties-page-plugin.h" line="44"/>
        <source>Peony Qt Share Extension</source>
        <translation>共享</translation>
    </message>
    <message>
        <location filename="../share-properties-page-plugin.h" line="45"/>
        <source>Allow user share folders</source>
        <translation>允许共享文件夹</translation>
    </message>
</context>
<context>
    <name>SharePage</name>
    <message>
        <location filename="../share-page.cpp" line="461"/>
        <source>Share folder</source>
        <translation>共享文件夹</translation>
    </message>
    <message>
        <source>Share:</source>
        <translation type="vanished">共享:</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="144"/>
        <source>The folder is currently shared in non-read-only mode, and setting up the share requires adding other people&apos;s write permissions to the current folder?</source>
        <translation>该文件夹当前共享模式为非只读模式，是否需要自动增加当前文件夹增加其他人的写权限？</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="125"/>
        <location filename="../share-page.cpp" line="145"/>
        <location filename="../share-page.cpp" line="199"/>
        <source>question</source>
        <translation>询问</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="147"/>
        <location filename="../share-page.cpp" line="201"/>
        <source>Confirm adding permissions</source>
        <translation>确定增加权限</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="148"/>
        <location filename="../share-page.cpp" line="202"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="110"/>
        <location filename="../share-page.cpp" line="115"/>
        <location filename="../share-page.cpp" line="176"/>
        <location filename="../share-page.cpp" line="185"/>
        <location filename="../share-page.cpp" line="231"/>
        <location filename="../share-page.cpp" line="241"/>
        <location filename="../share-page.cpp" line="285"/>
        <location filename="../share-page.cpp" line="322"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="110"/>
        <source>The share name must not contain %1, and cannot start with a dash (-) or whitespace, or end with whitespace.</source>
        <translation>共享名不能包含%1，并且不能以-开头或者空格开头，或者空格结尾</translation>
    </message>
    <message>
        <source>The folder is currently shared with anonymous access set, do I need to automatically increase the executable permissions of the current file and others in the ancestor directory?</source>
        <translation type="vanished">该文件夹当前共享设置了匿名访问，是否需要自动增加当前文件和其他人的可执行权限？</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="115"/>
        <source>The share name cannot be the same as the current user name</source>
        <translation>共享文件名不能和已有用系统户名一致</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="125"/>
        <source>The share name is already used by other users. You can rename the folder and then set the share.</source>
        <translation>此共享文件名称已经被其它用户使用，您可以尝试重命名文件夹后再设置共享。</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="198"/>
        <source>The folder is currently shared with anonymous access set, do I need to automatically add executable permissions for the current file and all other members of the parent directory?</source>
        <translation>该文件夹当前共享设置了匿名访问，是否需要自动增加当前文件和其他人的可执行权限？</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="285"/>
        <source>Shared configuration service exception, please confirm if there is an ongoing shared configuration operation, or please reset the share!</source>
        <translation>共享配置服务异常，请确认是否有正在进行的共享配置操作，或者请重新设置共享！</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="297"/>
        <source>Samba set user password</source>
        <translation>Samba设置用户密码</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="295"/>
        <source>Samba password:</source>
        <translation>Samba密码：</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="322"/>
        <source>Samba set password failed, Please re-enter!</source>
        <translation>Samba设置密码失败，请重新输入!</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="425"/>
        <source>usershare</source>
        <translation>本机共享</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="432"/>
        <location filename="../share-page.cpp" line="477"/>
        <source>share this folder</source>
        <translation>共享此文件夹</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="432"/>
        <location filename="../share-page.cpp" line="484"/>
        <source>don`t share this folder</source>
        <translation>不共享此文件夹</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="512"/>
        <source>Share name:</source>
        <translation>共享名：</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="517"/>
        <source>Allow others to create and delete files</source>
        <translation>允许其它人创建和删除文件</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="vanished">只读</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="520"/>
        <source>Allow Anonymous</source>
        <translation>允许游客访问</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="529"/>
        <source>Advanced Sharing</source>
        <translation>高级共享</translation>
    </message>
    <message>
        <location filename="../share-page.cpp" line="513"/>
        <source>Comment:</source>
        <translation>注释:</translation>
    </message>
</context>
</TS>
